#Renamefiles to escape from special characters

Usage:

from renamefile import rename_file

anystring = "?=)(/&%+^'^svhbgfvserbfgd.mp3"

anystring = rename_file(anystring)

print(anystring)

---------------------------------------------

Result:

svhbgfvserbfgd.mp3